==> pyxmake-1.18.0.post2.tar.gz: pyxmake-1.18.0.post2/README.md <==
[![PyPi](https://img.shields.io/static/v1?label=PyPi&message=1.18.0&color=informational&logo=pypi)](https://pypi.org/project/pyxmake/)
[![doi](https://img.shields.io/badge/DOI-10.5281%2Fzenodo.13352143-red.svg)](https://zenodo.org/records/13352143)
[![pipeline status](https://gitlab.com/dlr-sy/pyxmake/badges/master/pipeline.svg)]()

# PyXMake
PyXMake is a python-based, cross-platform build tool for compiling and distributing software projects and their documentation. The package provides harmonized software interfaces and predefined workflows to selected third-party developer tools with stricter default settings to simplify their handling. Experienced users can use a collection of distinct build classes to set up more elaborate builds jobs.
## Usage
The package is structured into different build classes, whereby each class represents one distinct build event with some presets. These classes can be accessed directly to create a custom python-based build script.
## Reference
Currently, the following SY-STM software projects are built and maintained by using PyXMake:
* [PyXMake](https://gitlab.com/dlr-sy/pyxmake) (User Guide & Reference Guide)
* [MCODAC]((https://gitlab.com/dlr-sy/mcodac) (Reference Guide, Libraries)
* [BEOS](https://gitlab.com/dlr-sy/beos) (Reference Guide, Libraries)
* [Boxbeam]((https://gitlab.com/dlr-sy/boxbeam) (Reference Guide, Libraries)
* [Displam]((https://gitlab.com/dlr-sy/displam) (Executable)
## Example
Please refer to the linked [repository](https://gitlab.com/dlr-sy/pyxmake) for additional application examples.
## Contact
* [Marc Garbade](mailto:marc.garbade@dlr.de)
## Support
* [List of Contributors](https://gitlab.com/dlr-sy/pyxmake/-/blob/master/CONTRIBUTING.md)

==> pyxmake-1.18.1.tar.gz: pyxmake-1.18.1/README.md <==
[![PyPi](https://img.shields.io/static/v1?label=PyPi&message=1.18.0&color=informational&logo=pypi)](https://pypi.org/project/pyxmake/)
[![doi](https://img.shields.io/badge/DOI-10.5281%2Fzenodo.13352143-red.svg)](https://zenodo.org/records/13352143)
[![pipeline status](https://gitlab.com/dlr-sy/pyxmake/badges/master/pipeline.svg)]()

# PyXMake
PyXMake is a python-based, cross-platform build tool for compiling and distributing software projects and their documentation. The package provides harmonized software interfaces and predefined workflows to selected third-party developer tools with stricter default settings to simplify their handling. Experienced users can use a collection of distinct build classes to set up more elaborate builds jobs.
## Usage
The package is structured into different build classes, whereby each class represents one distinct build event with some presets. These classes can be accessed directly to create a custom python-based build script.
## Reference
Currently, the following SY-STM software projects are built and maintained by using PyXMake:
* [PyXMake](https://gitlab.com/dlr-sy/pyxmake) (User Guide & Reference Guide)
* [MCODAC](https://gitlab.com/dlr-sy/mcodac) (Reference Guide, Libraries)
* [BEOS](https://gitlab.com/dlr-sy/beos) (Reference Guide, Libraries)
* [Boxbeam](https://gitlab.com/dlr-sy/boxbeam) (Reference Guide, Libraries)
* [Displam](https://gitlab.com/dlr-sy/displam) (Executable)
## Example
Please refer to the linked [repository](https://gitlab.com/dlr-sy/pyxmake) for additional application examples.
## Contact
* [Marc Garbade](mailto:marc.garbade@dlr.de)
## Support
* [List of Contributors](https://gitlab.com/dlr-sy/pyxmake/-/blob/master/CONTRIBUTING.md)
